<?php

namespace Drupal\graupl_components\Plugin\Layout;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Layout\LayoutDefault;
use Drupal\Core\Plugin\PluginFormInterface;

/**
 * Configurable breakout container layout plugin class.
 *
 * @internal
 *   Plugin classes are internal.
 */
class ContainedLayoutBase extends LayoutDefault implements PluginFormInterface {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    $configuration = parent::defaultConfiguration();
    return $configuration + [
      'contain' => 0,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['contain'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Contain'),
      '#default_value' => $this->configuration['contain'],
      '#description' => $this->t('Check this box to contain content in the content area.'),
    ];
    return parent::buildConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function build(array $regions) {
    $build = parent::build($regions);
    $build['#attributes']['class'] = [
      'layout',
      $this->getPluginDefinition()->getTemplate(),
      $this->configuration['contain'] ? 'contained-layout' : '',
      'container',
    ];

    return $build;
  }

}
